Pre Survey
-----------------------------------------------------

Think about **yourself and your learning** when answering the following questions.

==============

.. .. poll:: self-efficacy-1
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     I will be able to achieve most of the goals that I have set for myself.

.. .. poll:: self-efficacy-2
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     When facing difficult tasks, I am certain that I will accomplish them.

.. .. poll:: self-efficacy-3
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     In general, I think that I can obtain outcomes that are important to me.

.. .. poll:: self-efficacy-4
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     I believe I can succeed at most any endeavor to which I set my mind.

.. .. poll:: self-efficacy-5
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     I will be able to successfully overcome many challenges.

.. .. poll:: self-efficacy-6
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     I am confident that I can perform effectively on many different tasks.

.. .. poll:: self-efficacy-7
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     Compared to other people, I can do most tasks very well.

.. .. poll:: self-efficacy-8
..     :option_1: Strongly disagree
..     :option_2: Disagree
..     :option_3: Neither agree nor disagree
..     :option_4: Agree
..     :option_5: Strongly agree
..     :results: instructor

..     Even when things are tough, I can perform quite well.

.. poll:: CS-self-efficacy-1-N
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    Generally I have felt secure about attempting computer programming problems.

.. poll:: CS-self-efficacy-2-N
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I am sure I could do advanced work in computer science.

.. poll:: CS-self-efficacy-3-N
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I am sure that I can learn programming.

.. poll:: CS-self-efficacy-4-N
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I think I could handle more difficult programming problems.

.. poll:: CS-self-efficacy-5-N
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I can get good grades in computer science.

.. poll:: CS-self-efficacy-6-N
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I have a lot of self-confidence when it comes to programming.

For the next questions please select the answer that best
matches your familiarity and confidence
about the specified concept(s).

.. poll:: se-loop-7-N
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Loops/Iteration like <code>for n in nums:</code> and <code>for i in range(4):</code>

.. poll:: se-cond-8-N
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Conditionals/Selection Statements like <code>if x < 3:</code>

.. poll:: se-func-9-N
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Functions like <code>def get_odd(nums):</code>

.. poll:: se-list-dic-10-N
    :option_1: I am unfamiliar with these concepts
    :option_2: I know what they mean, but have not used them in a program
    :option_3: I have used these concepts in a program, but am not confident about my ability to use them
    :option_4: I am confident in my ability to use these concepts in simple programs
    :option_5: I am confident in my ability to use these concepts in complex programs
    :results: instructor

    Lists like <code>a = ["red", "green"]</code>.

Thanks for filling this survey and let us know you better!

What to do next
============================
.. raw:: html

    <h4>Click on the following link to start practice 👉 <b><a href="fl-write.html">Practice</a></b></h4>

